@@ -345,6 +345,7 @@ __all__ = (
 from io import BytesIO
 from weakref import WeakMethod, ref
 
+from kivy import Logger
 from kivy.clock import Clock
 from kivy.core.image import Image as CoreImage
 from kivy.lang import Builder
@@ -484,6 +485,9 @@ class CommonElevationBehavior(Widget):
 
 
             Example().run()
+
+    :attr:`elevation` is an :class:`~kivy.properties.BoundedNumericProperty`
+    and defaults to `0`.
     """
 
     # Shadow rendering properties.
@@ -921,7 +925,9 @@ class CommonElevationBehavior(Widget):
         Works similar to an `__after_init__` call inside a widget.
         """
 
-        if self.elevation is None:
+        from kivymd.uix.card import MDCard
+
+        if self.elevation is None and not issubclass(self.__class__, MDCard):
             self.elevation = 10
         if self._fake_elevation is False:
             self._update_shadow(self, self.elevation)
@@ -1113,12 +1119,14 @@ class CommonElevationBehavior(Widget):
         return center
 
     def __draw_shadow__(self, origin, end, context=None):
-        raise NotImplementedError(
-            "KivyMD:\n"
-            "If you see this error, this means that either youre using "
-            "`CommonElevationBehavio`r directly or your 'shader' dont have a "
-            "`_draw_shadow` instruction, remember to overwrite this function"
-            "to draw over the image context. the figure you would like."
+        Logger.warning(
+            f"KivyMD: "
+            f"If you see this error, this means that either youre using "
+            f"`CommonElevationBehavio`r directly or your 'shader' dont have a "
+            f"`_draw_shadow` instruction, remember to overwrite this function"
+            f"to draw over the image context. Тhe figure you would like. "
+            f"Or your class {self.__class__.__name__} is not inherited from "
+            f"any of the classes {__all__}"
         )
 
 
@@ -1323,20 +1331,6 @@ class FakeRectangularElevationBehavior(CommonElevationBehavior):
     `FakeCircularElevationBehavior` will load prefabricated textures to
     optimize loading times.
 
-    Also, this class allows you to overwrite real time shadows, in the sence that
-    if you are using a standard widget, like a button, MDCard or Toolbar, you can
-    include this class after the base class to optimize the loading times.
-
-    As an example of this flexibility:
-
-    .. code-block:: python
-
-        class Custom_rectangular_Card(
-            MDCard,
-            FakeRectangularElevationBehavior
-        ):
-            [...]
-
     .. note:: About rounded corners:
         be careful, since this behavior is a mockup and will not draw any
         rounded corners.
@@ -1383,8 +1377,8 @@ class FakeRectangularElevationBehavior(CommonElevationBehavior):
                 center_y - soft_height / 2 - dp(self._elevation * 0.5),
             )
             # Set transparency
-            self._soft_shadow_a = 0.1 * 1.05 ** self._elevation
-            self._hard_shadow_a = 0.4 * 0.8 ** self._elevation
+            self._soft_shadow_a = 0.1 * 1.05**self._elevation
+            self._hard_shadow_a = 0.4 * 0.8**self._elevation
             t = int(round(self._elevation))
             if 0 < t <= 23:
                 self._soft_shadow_texture = (
@@ -1430,20 +1424,6 @@ class FakeCircularElevationBehavior(CommonElevationBehavior):
     `FakeCircularElevationBehavior` will load prefabricated textures to optimize
     loading times.
 
-    Also, this class allows you to overwrite real time shadows, in the sence that
-    if you are using a standard widget, like a button, MDCard or Toolbar, you can
-    include this class afher the base class to optimize the loading times.
-
-    As an example of this flexibility:
-
-    .. code-block:: python
-
-        class Custom_Circular_Card(
-            MDCard,
-            FakeCircularElevationBehavior
-        ):
-            [...]
-
     .. note:: About rounded corners:
         be careful, since this behavior is a mockup and will not draw any rounded
         corners. only perfect ellipses.
@@ -1475,8 +1455,8 @@ class FakeCircularElevationBehavior(CommonElevationBehavior):
             self.hard_shadow_pos = (x, y)
 
             # shadow transparency
-            self._soft_shadow_a = 0.1 * 1.05 ** self._elevation
-            self._hard_shadow_a = 0.4 * 0.8 ** self._elevation
+            self._soft_shadow_a = 0.1 * 1.05**self._elevation
+            self._hard_shadow_a = 0.4 * 0.8**self._elevation
             t = int(round(self._elevation))
             if 0 < t <= 23:
                 if hasattr(self, "_shadow"):
