@@ -1,6 +1,6 @@
 """
-Components/Grid Layout
-======================
+Components/GridLayout
+=====================
 
 :class:`~kivy.uix.gridlayout.GridLayout` class equivalent. Simplifies working
 with some widget properties. For example:
@@ -65,7 +65,7 @@ Equivalent
 .. code-block:: kv
 
     size_hint_x: None
-    height: self.minimum_width
+    width: self.minimum_width
 
 .. adaptive_size:
 adaptive_size
@@ -86,7 +86,8 @@ Equivalent
 from kivy.uix.gridlayout import GridLayout
 
 from kivymd.uix import MDAdaptiveWidget
+from kivymd.uix.behaviors import DeclarativeBehavior
 
 
-class MDGridLayout(GridLayout, MDAdaptiveWidget):
+class MDGridLayout(DeclarativeBehavior, GridLayout, MDAdaptiveWidget):
     pass
